# provide-oracle

Provide oracle client for IoT applications. Proof of concept "message bus" application.

## Installation

`pip install prvdoracle`

## pipenv

`pipenv install` uses the Pipefile to install package dependencies.

## Usage

Documentation forthcoming.
